@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 Cisco, Inc.  All rights reserved.
+ * Copyright (c) 2012 Mellanox Technologies, Inc.  All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -30,34 +30,33 @@
  * SOFTWARE.
  */
 
+
 #ifndef DOORBELL_H
 #define DOORBELL_H
 
-#include "mmio.h"
-
 #if SIZEOF_LONG == 8
 
 #if __BYTE_ORDER == __LITTLE_ENDIAN
-#  define MLX4_PAIR_TO_64(val) ((uint64_t) val[1] << 32 | val[0])
+#  define MLX5_PAIR_TO_64(val) ((uint64_t) val[1] << 32 | val[0])
 #elif __BYTE_ORDER == __BIG_ENDIAN
-#  define MLX4_PAIR_TO_64(val) ((uint64_t) val[0] << 32 | val[1])
+#  define MLX5_PAIR_TO_64(val) ((uint64_t) val[0] << 32 | val[1])
 #else
 #  error __BYTE_ORDER not defined
 #endif
 
-static inline void mlx4_write64(uint32_t val[2], struct mlx4_context *ctx, int offset)
+static inline void mlx5_write64(uint32_t val[2], void *dest, struct mlx5_spinlock *lock)
 {
-	mmio_writeq((unsigned long)(ctx->uar + offset), MLX4_PAIR_TO_64(val));
+	*(volatile uint64_t *)dest = MLX5_PAIR_TO_64(val);
 }
 
 #else
 
-static inline void mlx4_write64(uint32_t val[2], struct mlx4_context *ctx, int offset)
+static inline void mlx5_write64(uint32_t val[2], void *dest, struct mlx5_spinlock *lock)
 {
-	pthread_spin_lock(&ctx->uar_lock);
-	mmio_writel((unsigned long)(ctx->uar + offset), val[0]);
-	mmio_writel((unsigned long)(ctx->uar + offset + 4), val[1]);
-	pthread_spin_unlock(&ctx->uar_lock);
+	mlx5_spin_lock(lock);
+	*(volatile uint32_t *)dest		= val[0];
+	*(volatile uint32_t *)(dest + 4)	= val[1];
+	mlx5_spin_unlock(lock);
 }
 
 #endif
